California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 056 - CIGARETTE TAX TO FUND HEALTHCARE, TOBACCO USE PREVENTION, RESEARCH, AND LAW ENFORCEMENT. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1385538 | CALIFORNIA KIDS CAMPAIGN, YES ON PROPS 55 & 56, SPONSORED AND MAJOR FUNDING BY COMMON SENSE KIDS ACTION, INC. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1389668 | YES ON 56 STOP CANCER - PLANNED PARENTHOOD OF ORANGE AND SAN BERNARDINO COUNTIES' COMMUNITY ACTION FUND (NON PROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1389484 | CALIFORNIA CITIZENS AGAINST SPECIAL INTERESTS AND WASTEFUL TAXES, NO ON PROP. 56 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1388518 | YES ON 56 STOP CANCER - PLANNED PARENTHOOD ADVOCATES MAR MONTE (NON PROFIT 501 (C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1390602 | COMMON SENSE KIDS ACTION, INC., YES ON PROPS. 55 AND 56 (NONPROFIT 501 (C) (4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1383858 | FIGHT CANCER - YES ON 56, SPONSORED BY AMERICAN CANCER SOCIETY, INC. AND AMERICAN CANCER SOCIETY CANCER ACTION NETWORK, INC. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372760 | PICO CALIFORNIA - YES ON 55, 56, AND 57 (NON PROFIT 501 (C) (3)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1391170 | MILLION VOTER PROJECT ACTION FUND - YES ON 55, 56, 57, 58, 62, AND NO ON 66, SPONSORED BY SOCIAL JUSTICE ADVOCATES AND ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1386637 | NO ON 56 - STOP THE SPECIAL INTEREST TAX GRAB. MAJOR FUNDING BY PHILIP MORRIS USA INC. AND R.J. REYNOLDS TOBACCO COMPANY, WITH A COALITION OF TAXPAYERS, EDUCATORS, HEALTHCARE PROFESSIONALS, LAW ... | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1388865 | PROTECT SMALL BUSINESS AND SMOKE FREE ALTERNATIVES, NO ON 56; SPONSORED BY SMOKE-FREE ALTERNATIVES TRADE ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1377991 | YES ON 56 - SAVES LIVES CALIFORNIA, A COALITION OF DOCTORS, DENTISTS, HEALTH PLANS, LABOR, HOSPITALS, LAW ENFORCEMENT, AND NON-PROFIT HEALTH ADVOCATE ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1384591 | MILLION VOTER PROJECT ACTION FUND - YES ON 55 AND 57, SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS | SUPPORT